# Subscription Roles
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/subscription-roles#introduction)
  * [Creating a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles#creating-a-subscription-role)
  * [Editing a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles#editing-a-subscription-role)
  * [Deleting a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles#deleting-a-subscription-role)
  * [Subscription Settings](https://help.sap.com/docs/leanix/ea/subscription-roles#subscription-settings)
  * [Enforcing Mandatory Selection of a Subscription Role](https://help.sap.com/docs/leanix/ea/subscription-roles#enforcing-mandatory-selection-of-a-subscription-role)
  * [Enabling the Subscription Type Accountable](https://help.sap.com/docs/leanix/ea/subscription-roles#enabling-the-subscription-type-accountable)
  * [Restricting Multiple Subscriptions from the Same User to a Fact Sheet](https://help.sap.com/docs/leanix/ea/subscription-roles#restricting-multiple-subscriptions-from-the-same-user-to-a-fact-sheet)


View all
Learn how to create, edit, and delete subscription roles and manage settings like enabling the 'Accountable' type, limiting multiple subscriptions, and enforcing mandatory role selection.
